@@ -14,13 +14,14 @@
 
 """
 Utils (:mod:`rectools.utils`)
-===================================
+=============================
 
 Inner helpers.
 
-===============================
+
 Tools
 -----
+`utils.fast_2d_int_unique`
 `utils.fast_isin`
 `utils.fast_isin_for_sorted_test_elements`
 `utils.get_element_ids`
@@ -29,15 +30,24 @@ Tools
 `utils.log_at_base`
 `utils.is_instance`
 `utils.select_by_type`
-===============================
 """
 
-from .indexing import fast_isin, fast_isin_for_sorted_test_elements, get_element_ids, get_from_series_by_index
+from .array_set_ops import (
+    fast_2d_2col_int_unique,
+    fast_2d_int_unique,
+    fast_isin,
+    fast_isin_for_sorted_test_elements,
+    isin_2d_int,
+)
+from .indexing import get_element_ids, get_from_series_by_index
 from .misc import is_instance, log_at_base, pairwise, select_by_type
 
 __all__ = (
+    "fast_2d_int_unique",
+    "fast_2d_2col_int_unique",
     "fast_isin",
     "fast_isin_for_sorted_test_elements",
+    "isin_2d_int",
     "get_element_ids",
     "get_from_series_by_index",
     "pairwise",
